summaryrefslogtreecommitdiffstats
path: root/libk3b/tools/libisofs/iso_fs.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 19:21:21 +0000
commitd8cc8bdfa7fa624a526d5aa1626974e1444cb799 (patch)
treef295f1c545b319963d5357af79fe08991d8141d9 /libk3b/tools/libisofs/iso_fs.h
parent2a39a080579fb52a2599c02b2939795385b89093 (diff)
downloadk3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.tar.gz
k3b-d8cc8bdfa7fa624a526d5aa1626974e1444cb799.zip
TQt4 port k3b
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k3b@1233803 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk3b/tools/libisofs/iso_fs.h')
-rw-r--r--libk3b/tools/libisofs/iso_fs.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libk3b/tools/libisofs/iso_fs.h b/libk3b/tools/libisofs/iso_fs.h
index 43353b0..b726b9f 100644
--- a/libk3b/tools/libisofs/iso_fs.h
+++ b/libk3b/tools/libisofs/iso_fs.h
@@ -131,13 +131,13 @@ struct hs_primary_descriptor {
char root_directory_record [ISODCL (181, 214)]; /* 9.1 */
};
/* We use this to help us look up the parent inode numbers. */
struct iso_path_table{
char name_len[1]; /* 711 */
char ext_attr_length[1]; /* 711 */
char extent[4]; /* 731 */
- char parent[2]; /* 721 */
+ char tqparent[2]; /* 721 */
char name[1];
};
@@ -131,13 +131,13 @@ struct hs_primary_descriptor {
char root_directory_record [ISODCL (181, 214)]; /* 9.1 */
};
-/* We use this to help us look up the parent inode numbers. */
+/* We use this to help us look up the tqparent inode numbers. */
struct iso_path_table{
char name_len[1]; /* 711 */